using System;
using System.Collections.Generic;
//+
namespace ESVBible.Service.Parameter
{
    /// <summary>
    /// Parameters representing the readingPlanInfo function, providing information about the readings for a given day.
    /// </summary>
    public class ReadingPlanInfoParameter : Parameter, IDefaultOptimization
    {
        //- @Date -//
        /// <summary>
        /// Get the reading plan for a certain date. Should be in YYYY-MM-DD format (e.g., 2007-11-17 for today). The date changes at midnight US Central Time (GMT -5 or -6). (Today's date)
        /// </summary>
        public String Date { get; set; }

        //- @ReadingPlan -//
        /// <summary>
        /// Specifies which reading plan to use. Possibilities are one-year-tract, through-the-bible, every-day-in-the-word, and bcp. For more information about these reading plans, please see our Devotions area at http://www.gnpcb.org/esv/devotions/. (default: one-year-tract)
        /// </summary>
        public ReadingPlan ReadingPlan { get; set; }

        //- @StartDate -//
        /// <summary>
        /// Specify a start date for the reading plan if you want to begin your readings at the beginning of the plan on dates besides January 1. Should be in YYYY-MM-DD format.
        /// </summary>
        public String StartDate { get; set; }

        //- $ReadingPlanDefault -//
        private ReadingPlan ReadingPlanDefault { get; set; }

        //+
        //- @ReadingPlanInfoParameters -//
        public ReadingPlanInfoParameter()
        {
            this.ReadingPlan = ReadingPlan.OneYearTract;
            this.ReadingPlanDefault = ReadingPlan.OneYearTract;
        }

        //+
        //- $IDefaultOptimization.GetSettingsList -//
        Dictionary<String, String> IDefaultOptimization.GetSettingsList()
        {
            Dictionary<String, String> d = new Dictionary<String, String>();
            //+
            if (!String.IsNullOrEmpty(this.Date)) ArgumentListManager.AddArgument(d, "date", this.Date);
            if (this.ReadingPlan != this.ReadingPlanDefault) ArgumentListManager.AddArgument(d, "reading-plan", TextTranslation.GetReadingPlanText(this.ReadingPlan));
            if (!String.IsNullOrEmpty(this.StartDate)) ArgumentListManager.AddArgument(d, "start-date", this.StartDate);
            //+
            return d;
        }
    }
}