using System;
using System.Collections.Generic;
//+
namespace ESVBible.Service.Setting
{
    public class HtmlOutputSetting : IOutputSetting, IDefaultOptimization
    {
        //- @AudioFormat -//
        /// <summary>
        /// Takes a value of flash, mp3, real, or wma to indicate the format of the audio. It defaults to flash, but the default could change; if you have a strong preference for one of these formats, we recommend that you specify it explicitly. We recommend flash as the most flexible; an embedded Flash player is included in the text. The mp3 option includes a link to an M3U file. However, this link expires after about 24 hours, making it unsuitable for extended caching. The other two options, real and wma, only have New Testament recordings by Marquis Laughlin available. (The real option refers to RealAudio, and wma refers to Windows Media.) (default: flash)
        /// </summary>
        public String AudioFormat { get; set; }

        //- @AudioVersion -//
        /// <summary>
        /// Which recording to use. The options are: mm (Max McLean, complete Bible), ml (Marquis Laughlin, New Testament only), and ml-mm (Max McLean for Old Testament, Marquis Laughlin for New Testament. Only affects the output if audio-format is flash or mp3. (Max McLean's version is only available in these two formats.) (default: mm)
        /// </summary>
        public String AudioVersion { get; set; }

        //- @IncludePassageReferences -//
        /// <summary>
        /// Include 'h2's that indicate which passage is being displayed. For example: Isaiah 53:1-5. (default: true)
        /// </summary>
        public Boolean IncludePassageReferences { get; set; }

        //- @IncludeFirstVerseNumbers -//
        /// <summary>
        /// Show the verse number (e.g., 53:1) at the beginnings of chapters. (default: true)
        /// </summary>
        public Boolean IncludeFirstVerseNumbers { get; set; }

        //- @IncludeVerseNumbers -//
        /// <summary>
        /// Show verse numbers in the text. (default: true)
        /// </summary>
        public Boolean IncludeVerseNumbers { get; set; }

        //- @IncludeFootnotes -//
        /// <summary>
        /// Include footnotes and references to them in the text. (default: true)
        /// </summary>
        public Boolean IncludeFootnotes { get; set; }

        //- @IncludeFootnoteLinks -//
        /// <summary>
        /// If you have set Includefootnotes to true, set this option to false to turn off the links to the footnotes within the text. The footnotes will still appear at the bottom of the passage. If Includefootnotes is false, this parameter does not do anything. (default: true)
        /// </summary>
        public Boolean IncludeFootnoteLinks { get; set; }

        //- @IncludeHeadings -//
        /// <summary>
        /// Include section headings. For example, the section heading of Matthew 5 is The Sermon on the Mount. (default: true)
        /// </summary>
        public Boolean IncludeHeadings { get; set; }

        //- @IncludeSubheadings -//
        /// <summary>
        /// Include subheadings. Subheadings are the titles of psalms (e.g., Psalm 73's A Maskil of Asaph), the acrostic divisions in Psalm 119, the speakers in Song of Solomon, and the textual notes that appear in John 7 and Mark 16. (default: true)
        /// </summary>
        public Boolean IncludeSubheadings { get; set; }

        //- @IncludeSurroundingChapters -//
        /// <summary>
        /// If you have set Includefootnotes to true, set this option to false to turn off the links to the footnotes within the text. The footnotes will still appear at the bottom of the passage. If Includefootnotes is false, this parameter does not do anything. (default: true)
        /// </summary>
        public Boolean IncludeSurroundingChapters { get; set; }

        //- @IncludeWordIds -//
        /// <summary>
        /// Include a 'span' tags surrounding each word with a unique id. The id has several parts; the id "w40001002.01-1" consists of: the letter w (needed for valid XHTML ids), an eight-digit verse identifier (40001002 indicates Matthew 1:2), a period (.), a two-digit word identifier (01), and a hyphen followed by a number (this number is incremented with each passage; it starts with 1). Footnotes do not have word ids. (default: false)
        /// </summary>
        public Boolean IncludeWordIds { get; set; }

        //- @IncludeAudioLink -//
        /// <summary>
        /// Include a link to the audio version of the requested passage. The link appears in a 'small' tag in the passage's identifying 'h2'. (default: true)
        /// </summary>
        public Boolean IncludeAudioLink { get; set; }

        //- @IncludeShortCopyright -//
        /// <summary>
        /// Each passage from the ESV needs to include the letters "ESV" at the end of the passage. To turn off this behavior, set this option to false. (default: true)
        /// </summary>
        public Boolean IncludeShortCopyright { get; set; }

        //- @IncludeCopyright -//
        /// <summary>
        /// Show a copyright notice at the bottom of the text. Any page that shows the ESV text from this service needs to include a copyright notice, but you do not need to include it with each passage. Best practice is probably to include the copyright manually on your page, rather than download it every time. This option is mutually exclusive with Includeshort-copyright, which overrides Includecopyright. (default: false)
        /// </summary>
        public Boolean IncludeCopyright { get; set; }

        //- @LinkUrl -//
        /// <summary>
        /// Where embedded links to other passages should point. It currently applies only when Includesurrounding-chapters is set to true. (default: http://www.gnpcb.org/esv/search/)
        /// </summary>
        public String LinkUrl { get; set; }

        //+
        //- $IncludePassageReferencesDefault -//
        private Boolean IncludePassageReferencesDefault { get; set; }

        //- $IncludeFirstVerseNumbersDefault -//
        private Boolean IncludeFirstVerseNumbersDefault { get; set; }

        //- $IncludeVerseNumbersDefault -//
        private Boolean IncludeVerseNumbersDefault { get; set; }

        //- $IncludeFootnotesDefault -//
        private Boolean IncludeFootnotesDefault { get; set; }

        //- $IncludeFootnoteLinksDefault -//
        private Boolean IncludeFootnoteLinksDefault { get; set; }

        //- $IncludeHeadingsDefault -//
        private Boolean IncludeHeadingsDefault { get; set; }

        //- $IncludeSubheadingsDefault -//
        private Boolean IncludeSubheadingsDefault { get; set; }

        //- $IncludeSurroundingChaptersDefault -//
        private Boolean IncludeSurroundingChaptersDefault { get; set; }

        //- $IncludeWordIdsDefault -//
        private Boolean IncludeWordIdsDefault { get; set; }

        //- $LinkUrlDefault -//
        private String LinkUrlDefault { get; set; }

        //- $IncludeAudioLinkDefault -//
        private Boolean IncludeAudioLinkDefault { get; set; }

        //- $AudioFormatDefault -//
        private String AudioFormatDefault { get; set; }

        //- $AudioVersionDefault -//
        private String AudioVersionDefault { get; set; }

        //- $IncludeShortCopyrightDefault -//
        private Boolean IncludeShortCopyrightDefault { get; set; }

        //- $IncludeCopyrightDefault -//
        private Boolean IncludeCopyrightDefault { get; set; }

        //+
        //- @Timeout -//
        /// <summary>
        /// Time in seconds to wait before failing the service call
        /// </summary>
        public Int32 Timeout { get; set; }

        //+
        //- @Ctor -//
        public HtmlOutputSetting()
        {
            this.IncludePassageReferences = true;
            this.IncludeFirstVerseNumbers = true;
            this.IncludeVerseNumbers = true;
            this.IncludeFootnotes = true;
            this.IncludeFootnoteLinks = true;
            this.IncludeHeadings = true;
            this.IncludeSubheadings = true;
            this.IncludeSurroundingChapters = false;
            this.IncludeWordIds = false;
            this.IncludeAudioLink = true;
            this.IncludeShortCopyright = true;
            this.IncludeCopyright = false;

            this.IncludePassageReferencesDefault = true;
            this.IncludeFirstVerseNumbersDefault = true;
            this.IncludeVerseNumbersDefault = true;
            this.IncludeFootnotesDefault = true;
            this.IncludeFootnoteLinksDefault = true;
            this.IncludeHeadingsDefault = true;
            this.IncludeSubheadingsDefault = true;
            this.IncludeSurroundingChaptersDefault = false;
            this.IncludeWordIdsDefault = false;
            this.IncludeAudioLinkDefault = true;
            this.IncludeShortCopyrightDefault = true;
            this.IncludeCopyrightDefault = false;
        }

        //+
        //- $IDefaultOptimization.GetSettingsList -//
        Dictionary<String, String> IDefaultOptimization.GetSettingsList()
        {
            Dictionary<String, String> d = new Dictionary<String, String>();
            //+
            if (this.IncludePassageReferences != this.IncludePassageReferencesDefault) ArgumentListManager.AddArgument(d, "include-passage-references", this.IncludePassageReferences);
            if (this.IncludeFirstVerseNumbers != this.IncludeFirstVerseNumbersDefault) ArgumentListManager.AddArgument(d, "include-first-verse-numbers", this.IncludeFirstVerseNumbers);
            if (this.IncludeVerseNumbers != this.IncludeVerseNumbersDefault) ArgumentListManager.AddArgument(d, "include-verse-numbers", this.IncludeVerseNumbers);
            if (this.IncludeFootnotes != this.IncludeFootnotesDefault) ArgumentListManager.AddArgument(d, "include-footnotes", this.IncludeFootnotes);
            if (this.IncludeFootnoteLinks != this.IncludeFootnoteLinksDefault) ArgumentListManager.AddArgument(d, "include-footnote-links", this.IncludeFootnoteLinks);
            if (this.IncludeHeadings != this.IncludeHeadingsDefault) ArgumentListManager.AddArgument(d, "include-headings", this.IncludeHeadings);
            if (this.IncludeSubheadings != this.IncludeSubheadingsDefault) ArgumentListManager.AddArgument(d, "include-subheadings", this.IncludeSubheadings);
            if (this.IncludeSurroundingChapters != this.IncludeSurroundingChaptersDefault) ArgumentListManager.AddArgument(d, "include-surrounding-chapters", this.IncludeSurroundingChapters);
            if (this.IncludeWordIds != this.IncludeWordIdsDefault) ArgumentListManager.AddArgument(d, "include-word-ids", this.IncludeWordIds);
            if (this.IncludeAudioLink != this.IncludeAudioLinkDefault) ArgumentListManager.AddArgument(d, "include-audio-link", this.IncludeAudioLink);
            if (this.IncludeShortCopyright != this.IncludeShortCopyrightDefault) ArgumentListManager.AddArgument(d, "include-short-copyright", this.IncludeShortCopyright);
            if (this.IncludeCopyright != this.IncludeCopyrightDefault) ArgumentListManager.AddArgument(d, "include-copyright", this.IncludeCopyright);
            if (!String.IsNullOrEmpty(this.LinkUrl)) ArgumentListManager.AddArgument(d, "link-url", this.LinkUrl);
            if (!String.IsNullOrEmpty(this.AudioFormat)) ArgumentListManager.AddArgument(d, "audio-format", this.AudioFormat);
            if (!String.IsNullOrEmpty(this.AudioVersion)) ArgumentListManager.AddArgument(d, "audio-version", this.AudioVersion);
            //+
            return d;
        }
    }
}