using System;
using System.Collections.Generic;
//+
namespace ESVBible.Service.Setting
{
    public class PlainTextSetting : IOutputSetting, IDefaultOptimization
    {
        //- @IncludeContentType -//
        /// <summary>
        /// Adds a Content-Type: text/plain HTTP header. Set to false if you want the default content type. (For example, in an RSS feed you want the content type to remain text/xml). (default: true)
        /// </summary>
        public Boolean IncludeContentType { get; set; }

        //- @IncludeCopyright -//
        /// <summary>
        /// Show a copyright notice at the bottom of the text. Any page that shows the ESV text from this service needs to include a copyright notice, but you do not need to include it with each passage. Best practice is probably to include the copyright manually on your page, rather than download it every time. This option is mutually exclusive with include-short-copyright, which overrides include-copyright. (default: false)
        /// </summary>
        public Boolean IncludeCopyright { get; set; }

        //- @IncludeFirstVerseNumbers -//
        /// <summary>
        /// Show the verse number at the beginnings of chapters. In the example below, [23:1]. (default: true)
        /// </summary>
        public Boolean IncludeFirstVerseNumbers { get; set; }

        //- @IncludeFootnotes -//
        /// <summary>
        /// Show references to footnotes in the text in parentheses, and include the text of the footnotes at the bottom of the text. (default: true)
        /// </summary>
        public Boolean IncludeFootnotes { get; set; }

        //- @IncludeShortCopyright -//
        /// <summary>
        /// Each passage from the ESV needs to include the letters "ESV" at the end of the passage. To turn off this behavior, set this option to false. (default: true)
        /// </summary>
        public Boolean IncludeShortCopyright { get; set; }

        //- @IncludeHeadingHorizontalLines -//
        /// <summary>
        /// Include a line of underscores (___) above each section heading. (default: true)
        /// </summary>
        public Boolean IncludeHeadingHorizontalLines { get; set; }

        //- @IncludeHeadings -//
        /// <summary>
        /// Include section headings. In the below example, Seven Woes to the Scribes and Pharisees. (default: true)
        /// </summary>
        public Boolean IncludeHeadings { get; set; }

        //- @IncludePassageHorizontalLines -//
        /// <summary>
        /// Include a line of equals signs (===) above the beginning of each passage. (default: true)
        /// </summary>
        public Boolean IncludePassageHorizontalLines { get; set; }

        //- @IncludePassageReferences -//
        /// <summary>
        ///  	Include a line saying which passage is being displayed. In the example below, Matthew 22:43 - 23:1. (default: true)
        /// </summary>
        public Boolean IncludePassageReferences { get; set; }

        //- @IncludeSubheadings -//
        /// <summary>
        /// Include subheadings. Subheadings are the titles of psalms (e.g., Psalm 73's A Maskil of Asaph), the acrostic divisions in Psalm 119, the speakers in Song of Solomon, and the textual notes that appear in John 7 and Mark 16. (default: true)
        /// </summary>
        public Boolean IncludeSubheadings { get; set; }

        //- @IncludeSelahs -//
        /// <summary>
        /// Include Selahs, which are found mostly in the Psalms (e.g., Psalm 46:3). (default: true)
        /// </summary>
        public Boolean IncludeSelahs { get; set; }

        //- @IncludeVerseNumbers -//
        /// <summary>
        /// Show verse numbers in brackets. (default: true)
        /// </summary>
        public Boolean IncludeVerseNumbers { get; set; }

        //- @LineLength -//
        /// <summary>
        /// How long to make each line. Can be any integer 36 and over. Set to 0 for unlimited length--each paragraph or line of poetry will be on a separate line. (default: true)
        /// </summary>
        public Int32 LineLength { get; set; }

        //+
        //- $IncludePassageReferencesDefault -//
        private Boolean IncludePassageReferencesDefault { get; set; }

        //- $IncludeFirstVerseNumbersDefault -//
        private Boolean IncludeFirstVerseNumbersDefault { get; set; }

        //- $IncludeVerseNumbersDefault -//
        private Boolean IncludeVerseNumbersDefault { get; set; }

        //- $IncludeFootnotesDefault -//
        private Boolean IncludeFootnotesDefault { get; set; }

        //- $IncludeShortCopyrightDefault -//
        private Boolean IncludeShortCopyrightDefault { get; set; }

        //- $IncludeCopyrightDefault -//
        private Boolean IncludeCopyrightDefault { get; set; }

        //- $IncludePassageHorizontalLinesDefault -//
        private Boolean IncludePassageHorizontalLinesDefault { get; set; }

        //- $IncludeHeadingHorizontalLinesDefault -//
        private Boolean IncludeHeadingHorizontalLinesDefault { get; set; }

        //- $IncludeHeadingsDefault -//
        private Boolean IncludeHeadingsDefault { get; set; }

        //- $IncludeSubheadingsDefault -//
        private Boolean IncludeSubheadingsDefault { get; set; }

        //- $IncludeSelahsDefault -//
        private Boolean IncludeSelahsDefault { get; set; }

        //- $IncludeContentTypeDefault -//
        private Boolean IncludeContentTypeDefault { get; set; }

        //- $LineLengthDefault -//
        private Int32 LineLengthDefault { get; set; }

        //+
        //- @Timeout -//
        /// <summary>
        /// Time in seconds to wait before failing the service call
        /// </summary>
        public Int32 Timeout { get; set; }

        //+
        //- @Ctor -//
        public PlainTextSetting()
        {
            this.IncludePassageReferences = true;
            this.IncludeFirstVerseNumbers = true;
            this.IncludeVerseNumbers = true;
            this.IncludeFootnotes = true;
            this.IncludeShortCopyright = true;
            this.IncludeCopyright = false;
            this.IncludePassageHorizontalLines = true;
            this.IncludeHeadingHorizontalLines = true;
            this.IncludeHeadings = true;
            this.IncludeSubheadings = true;
            this.IncludeSelahs = true;
            this.IncludeContentType = true;
            this.LineLength = 74;

            this.IncludePassageReferencesDefault = true;
            this.IncludeFirstVerseNumbersDefault = true;
            this.IncludeVerseNumbersDefault = true;
            this.IncludeFootnotesDefault = true;
            this.IncludeShortCopyrightDefault = true;
            this.IncludeCopyrightDefault = false;
            this.IncludePassageHorizontalLinesDefault = true;
            this.IncludeHeadingHorizontalLinesDefault = true;
            this.IncludeHeadingsDefault = true;
            this.IncludeSubheadingsDefault = true;
            this.IncludeSelahsDefault = true;
            this.IncludeContentTypeDefault = true;
            this.LineLengthDefault = 74;
        }

        //+
        //- $IDefaultOptimization.GetSettingsList -//
        Dictionary<String, String> IDefaultOptimization.GetSettingsList()
        {
            Dictionary<String, String> d = new Dictionary<String, String>();
            //+
            ArgumentListManager.AddArgument(d, "output-format", "plain-text");
            if (this.IncludePassageReferences != this.IncludePassageReferencesDefault) ArgumentListManager.AddArgument(d, "include-passage-references", this.IncludePassageReferences);
            if (this.IncludeFirstVerseNumbers != this.IncludeFirstVerseNumbersDefault) ArgumentListManager.AddArgument(d, "include-first-verse-numbers", this.IncludeFirstVerseNumbers);
            if (this.IncludeVerseNumbers != this.IncludeVerseNumbersDefault) ArgumentListManager.AddArgument(d, "include-verse-numbers", this.IncludeVerseNumbers);
            if (this.IncludeFootnotes != this.IncludeFootnotesDefault) ArgumentListManager.AddArgument(d, "include-footnotes", this.IncludeFootnotes);
            if (this.IncludeShortCopyright != this.IncludeShortCopyrightDefault) ArgumentListManager.AddArgument(d, "include-short-copyright", this.IncludeShortCopyright);
            if (this.IncludeCopyright != this.IncludeCopyrightDefault) ArgumentListManager.AddArgument(d, "include-copyright", this.IncludeCopyright);
            if (this.IncludePassageHorizontalLines != this.IncludePassageHorizontalLinesDefault) ArgumentListManager.AddArgument(d, "include-passage-horizontal-lines", this.IncludePassageHorizontalLines);
            if (this.IncludeHeadingHorizontalLines != this.IncludeHeadingHorizontalLinesDefault) ArgumentListManager.AddArgument(d, "include-heading-horizontal-lines", this.IncludeHeadingHorizontalLines);
            if (this.IncludeHeadings != this.IncludeHeadingsDefault) ArgumentListManager.AddArgument(d, "include-headings", this.IncludeHeadings);
            if (this.IncludeSubheadings != this.IncludeSubheadingsDefault) ArgumentListManager.AddArgument(d, "include-subheadings", this.IncludeSubheadings);
            if (this.IncludeSelahs != this.IncludeSelahsDefault) ArgumentListManager.AddArgument(d, "include-selahs", this.IncludeSelahs);
            if (this.IncludeContentType != this.IncludeContentTypeDefault) ArgumentListManager.AddArgument(d, "include-content-type", this.IncludeContentType);
            if (this.LineLength != this.LineLengthDefault) ArgumentListManager.AddArgument(d, "line-length", this.LineLength);
            //+
            return d;
        }
    }
}